@@ -45,6 +45,7 @@ class CancelSponsorship(Transaction):
 
     def to_json(self):
         return (crypto.merge_dicts({
+            "id": self.id if self.id else "",
             "type": self.TYPE,
             "version": self.version,
             "senderKeyType": self.sender_key_type,
@@ -53,7 +54,8 @@ class CancelSponsorship(Transaction):
             "senderPublicKey": self.sender_public_key,
             "timestamp": self.timestamp,
             "fee": self.tx_fee,
-            "proofs": self.proofs
+            "proofs": self.proofs,
+            "height": self.height if self.height else ""
         }, self._sponsor_json()))
 
     @staticmethod
